@@ -1,13 +1,13 @@
 ### This is a python package used for configuring a Morpheus appliance ###
 
-from .infra.groups import (
-   *
-)
-
 from .appliance import (
    appliance
 )
 
+from .infra import (
+   infra
+)
+
 # from .configs import (
 #     createMorpheusGroup,
 #     createMorpheusAwsCloud,
